@@ -1,25 +1,20 @@
+from IteratorFlow import IteratorFlow
+from folderUtils import get_extension
 import os
 
 
-class FolderIterator:
+class FolderIterator(IteratorFlow):
     def __init__(self, filetypes=()):
+        self.filetypes = []
         if filetypes:
-            self.filetypes = tuple([filetype.lower() for filetype in filetypes])
-
-    def on_folder(self, path, name):
-        pass
-
-    def on_file(self, path, name):
-        pass
-
-    def on_filetype(self, path, name, ext):
-        pass
+            self.filetypes = tuple([filetype.lower()
+                                    for filetype in filetypes])
 
     def iterate(self, path):
         for root, dirs, files in os.walk(path):
             for name in files:
                 self.on_file(root, name)
-                ext = os.path.splitext(name)[-1].lower()
+                ext = get_extension(name)
                 if ext in self.filetypes:
                     self.on_filetype(root, name, ext)
             for name in dirs:
